/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef NU8 tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg[9];
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipTypes__ast_3723)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kinds);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5258)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, ithField__semmacrosanity_53)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, NI* field);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, ithField__semmacrosanity_5)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI* field);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, lastSon__ast_4833)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_3)(NI x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_625)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_167)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_1441)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(void, annotateType__semmacrosanity_69)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
static N_INLINE(NI, len__ast_3990)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNodeI__ast_3320)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_4798)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* father, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newIntNode__ast_3711)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind, NI64 intVal);
N_LIB_PRIVATE N_NIMCALL(void, genericAssign)(void* dest, void* src, TNimType* mt);
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, elemType__types_263)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__R7okQSC9beJ64olJCnqhGsw_2 = {
0x10, 0xa9, 0x10, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__R7okQSC9beJ64olJCnqhGsw_3 = {
0x10, 0xa9, 0xe0, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__R7okQSC9beJ64olJCnqhGsw_4 = {
0x10, 0x09, 0xe0, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__R7okQSC9beJ64olJCnqhGsw_5, "invalid field at index ", 23);
STRING_LITERAL(TM__R7okQSC9beJ64olJCnqhGsw_7, "/home/runner/work/nightlies/nightlies/nim/compiler/semmacrosanity.nim", 69);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__R7okQSC9beJ64olJCnqhGsw_6 = {((NimStringDesc*) &TM__R7okQSC9beJ64olJCnqhGsw_7),
((NI) 58),
((NI) 20)}
;
STRING_LITERAL(TM__R7okQSC9beJ64olJCnqhGsw_8, "(", 1);
STRING_LITERAL(TM__R7okQSC9beJ64olJCnqhGsw_9, ", ", 2);
STRING_LITERAL(TM__R7okQSC9beJ64olJCnqhGsw_10, ")", 1);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__R7okQSC9beJ64olJCnqhGsw_11 = {((NimStringDesc*) &TM__R7okQSC9beJ64olJCnqhGsw_7),
((NI) 60),
((NI) 22)}
;
extern NIM_CONST tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw unknownLineInfo__lineinfos_284;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__R7okQSC9beJ64olJCnqhGsw_12 = {((NimStringDesc*) &TM__R7okQSC9beJ64olJCnqhGsw_7),
((NI) 66),
((NI) 35)}
;
STRING_LITERAL(TM__R7okQSC9beJ64olJCnqhGsw_13, "Incorrectly generated tuple constr", 34);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__R7okQSC9beJ64olJCnqhGsw_14 = {((NimStringDesc*) &TM__R7okQSC9beJ64olJCnqhGsw_7),
((NI) 87),
((NI) 21)}
;
extern TNimType NTItnode__uh9cWvEa5Ty85PXOtuP5emw_;
STRING_LITERAL(TM__R7okQSC9beJ64olJCnqhGsw_15, "() must have a tuple type", 25);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__R7okQSC9beJ64olJCnqhGsw_16 = {((NimStringDesc*) &TM__R7okQSC9beJ64olJCnqhGsw_7),
((NI) 92),
((NI) 17)}
;
STRING_LITERAL(TM__R7okQSC9beJ64olJCnqhGsw_17, "[] must have some form of array type", 36);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__R7okQSC9beJ64olJCnqhGsw_18 = {((NimStringDesc*) &TM__R7okQSC9beJ64olJCnqhGsw_7),
((NI) 98),
((NI) 17)}
;
STRING_LITERAL(TM__R7okQSC9beJ64olJCnqhGsw_19, "{} must have the set type", 25);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__R7okQSC9beJ64olJCnqhGsw_20 = {((NimStringDesc*) &TM__R7okQSC9beJ64olJCnqhGsw_7),
((NI) 104),
((NI) 17)}
;
STRING_LITERAL(TM__R7okQSC9beJ64olJCnqhGsw_21, "float literal must have some float type", 39);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__R7okQSC9beJ64olJCnqhGsw_22 = {((NimStringDesc*) &TM__R7okQSC9beJ64olJCnqhGsw_7),
((NI) 109),
((NI) 17)}
;
STRING_LITERAL(TM__R7okQSC9beJ64olJCnqhGsw_23, "integer literal must have some int type", 39);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__R7okQSC9beJ64olJCnqhGsw_24 = {((NimStringDesc*) &TM__R7okQSC9beJ64olJCnqhGsw_7),
((NI) 114),
((NI) 17)}
;
STRING_LITERAL(TM__R7okQSC9beJ64olJCnqhGsw_25, "string literal must be of some string type", 42);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__R7okQSC9beJ64olJCnqhGsw_26 = {((NimStringDesc*) &TM__R7okQSC9beJ64olJCnqhGsw_7),
((NI) 119),
((NI) 17)}
;
STRING_LITERAL(TM__R7okQSC9beJ64olJCnqhGsw_27, "nil literal must be of some pointer type", 40);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__R7okQSC9beJ64olJCnqhGsw_28 = {((NimStringDesc*) &TM__R7okQSC9beJ64olJCnqhGsw_7),
((NI) 124),
((NI) 17)}
;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5211;
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5258((&gch__system_5211.zct), c);
}
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5307(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5264(src);
		incRef__system_5302(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5264((*dest));
		decRef__system_5309(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, ithField__semmacrosanity_5)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NI* field) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
{	result = NIM_NIL;
	result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 138):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					result = ithField__semmacrosanity_5((*n)._kind_6.sons->data[i], field);
					{
						if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA7_;
						goto BeforeRet_;
					}
					LA7_: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 139):
	{
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA12_;
			goto BeforeRet_;
		}
		LA12_: ;
		result = ithField__semmacrosanity_5((*n)._kind_6.sons->data[((NI) 0)], field);
		{
			if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA16_;
			goto BeforeRet_;
		}
		LA16_: ;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3155(n);
			i_4 = ((NI) 1);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA20;
					i_3 = i_4;
					switch ((*(*n)._kind_6.sons->data[i_3]).kind) {
					case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 85):
					case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 88):
					{
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T22_;
						T22_ = NIM_NIL;
						T22_ = lastSon__ast_4833((*n)._kind_6.sons->data[i_3]);
						result = ithField__semmacrosanity_5(T22_, field);
						{
							if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA25_;
							goto BeforeRet_;
						}
						LA25_: ;
					}
					break;
					default:
					{
					}
					break;
					}
					i_4 += ((NI) 1);
				} LA20: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		{
			if (!((*field) == ((NI) 0))) goto LA31_;
			result = (*n)._kind_4.sym;
		}
		goto LA29_;
		LA31_: ;
		{
			(*field) -= ((NI) 1);
		}
		LA29_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, ithField__semmacrosanity_53)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, NI* field) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* base;
{	result = NIM_NIL;
	base = (*t).sons->data[((NI) 0)];
	{
		while (1) {
			tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* b;
			if (!!((base == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA2;
			b = skipTypes__ast_3723(base, TM__R7okQSC9beJ64olJCnqhGsw_4);
			result = ithField__semmacrosanity_5((*b).n, field);
			{
				if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA5_;
				goto BeforeRet_;
			}
			LA5_: ;
			base = (*b).sons->data[((NI) 0)];
		} LA2: ;
	}
	result = ithField__semmacrosanity_5((*t).n, field);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x) {
	addInt__stdZprivateZdigitsutils_167(result, ((NI64) (x)));
}
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_625)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = resizeString(result, (info.Field0 ? info.Field0->Sup.len : 0) + 0);
appendString(result, info.Field0);
	{
		if (!(((NI) 0) < info.Field1)) goto LA3_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__R7okQSC9beJ64olJCnqhGsw_8));
		addInt__stdZprivateZdigitsutils_189((&result), info.Field1);
		{
			if (!(((NI) 0) < (NI)(info.Field2 + ((NI) 1)))) goto LA7_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__R7okQSC9beJ64olJCnqhGsw_9));
			addInt__stdZprivateZdigitsutils_189((&result), (NI)(info.Field2 + ((NI) 1)));
		}
		LA7_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__R7okQSC9beJ64olJCnqhGsw_10));
	}
	LA3_: ;
	return result;
}
static N_INLINE(NI, len__ast_3990)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n).sons ? (*n).sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__ast_3155(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, annotateType__semmacrosanity_69)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* x;
	x = skipTypes__ast_3723(t, TM__R7okQSC9beJ64olJCnqhGsw_2);
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 38):
	{
		tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* x_2;
		x_2 = skipTypes__ast_3723(t, TM__R7okQSC9beJ64olJCnqhGsw_3);
		asgnRef((void**) (&(*n).typ), t);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 1);
			{
				while (1) {
					NI j;
					tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* field;
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					j = (NI)(i - ((NI) 1));
					field = ithField__semmacrosanity_53(x_2, (&j));
					{
						NimStringDesc* T9_;
						NimStringDesc* T10_;
						if (!(field == 0)) goto LA7_;
						T9_ = NIM_NIL;
						T10_ = NIM_NIL;
						T10_ = dollar___systemZdollars_3(i);
						T9_ = rawNewString((T10_ ? T10_->Sup.len : 0) + 23);
appendString(T9_, ((NimStringDesc*) &TM__R7okQSC9beJ64olJCnqhGsw_5));
appendString(T9_, T10_);
						liMessage__msgs_1128(conf, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T9_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 2), TM__R7okQSC9beJ64olJCnqhGsw_6, NIM_FALSE);
					}
					goto LA5_;
					LA7_: ;
					{
						{
							NimStringDesc* argX60gensym16_;
							if (!!(((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34)))) goto LA14_;
							argX60gensym16_ = toFileLineCol__msgs_625(TM__R7okQSC9beJ64olJCnqhGsw_11);
							internalErrorImpl__msgs_1441(conf, unknownLineInfo__lineinfos_284, argX60gensym16_, TM__R7okQSC9beJ64olJCnqhGsw_11);
						}
						LA14_: ;
						annotateType__semmacrosanity_69((*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 1)], (*field).typ, conf);
					}
					LA5_: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 37):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 160):
	{
		{
			if (!((*x).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 18))) goto LA19_;
			asgnRef((void**) (&(*n).typ), t);
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = len__ast_3155(n);
				i_4 = ((NI) 0);
				{
					while (1) {
						if (!(i_4 < colontmp__2)) goto LA23;
						i_3 = i_4;
						{
							NI T26_;
							NimStringDesc* T29_;
							NimStringDesc* T30_;
							T26_ = (NI)0;
							T26_ = len__ast_3990(x);
							if (!(T26_ <= i_3)) goto LA27_;
							T29_ = NIM_NIL;
							T30_ = NIM_NIL;
							T30_ = dollar___systemZdollars_3(i_3);
							T29_ = rawNewString((T30_ ? T30_->Sup.len : 0) + 23);
appendString(T29_, ((NimStringDesc*) &TM__R7okQSC9beJ64olJCnqhGsw_5));
appendString(T29_, T30_);
							liMessage__msgs_1128(conf, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T29_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 2), TM__R7okQSC9beJ64olJCnqhGsw_12, NIM_FALSE);
						}
						goto LA24_;
						LA27_: ;
						{
							annotateType__semmacrosanity_69((*n)._kind_6.sons->data[i_3], (*x).sons->data[i_3], conf);
						}
						LA24_: ;
						i_4 += ((NI) 1);
					} LA23: ;
				}
			}
		}
		goto LA17_;
		LA19_: ;
		{
			NIM_BOOL T33_;
			T33_ = (NIM_BOOL)0;
			T33_ = ((*x).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 25));
			if (!(T33_)) goto LA34_;
			T33_ = ((*x).callConv == ((tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg) 9));
			LA34_: ;
			if (!T33_) goto LA35_;
			asgnRef((void**) (&(*n).typ), t);
		}
		goto LA17_;
		LA35_: ;
		{
			if (!((*x).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27))) goto LA38_;
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* bracketExpr;
				NI left;
				NI right;
				if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 160))) goto LA42_;
				bracketExpr = newNodeI__ast_3320(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41), (*n).info);
				left = ((NI) ((*(*n)._kind_6.sons->data[((NI) 1)])._kind_1.intVal));
				right = ((NI) ((*(*n)._kind_6.sons->data[((NI) 2)])._kind_1.intVal));
				(*bracketExpr).flags = (*n).flags;
				switch ((*(*n)._kind_6.sons->data[((NI) 0)]).kind) {
				case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
				{
					{
						NI i_5;
						NI res;
						i_5 = (NI)0;
						res = left;
						{
							while (1) {
								tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T48_;
								NI T49_;
								if (!(res <= right)) goto LA47;
								i_5 = res;
								T48_ = NIM_NIL;
								T48_ = newIntNode__ast_3711(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5), ((NI64) (((NU8)((*(*n)._kind_6.sons->data[((NI) 0)])._kind_3.strVal->data[i_5])))));
								add__ast_4798(bracketExpr, T48_);
								T49_ = (NI)0;
								T49_ = len__ast_3155(bracketExpr);
								annotateType__semmacrosanity_69((*bracketExpr)._kind_6.sons->data[(NI)(T49_ - ((NI) 1))], (*t).sons->data[((NI) 0)], conf);
								res += ((NI) 1);
							} LA47: ;
						}
					}
				}
				break;
				case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41):
				{
					{
						NI i_6;
						NI res_2;
						i_6 = (NI)0;
						res_2 = left;
						{
							while (1) {
								NI T54_;
								if (!(res_2 <= right)) goto LA53;
								i_6 = res_2;
								add__ast_4798(bracketExpr, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[i_6]);
								T54_ = (NI)0;
								T54_ = len__ast_3155(bracketExpr);
								annotateType__semmacrosanity_69((*bracketExpr)._kind_6.sons->data[(NI)(T54_ - ((NI) 1))], (*t).sons->data[((NI) 0)], conf);
								res_2 += ((NI) 1);
							} LA53: ;
						}
					}
				}
				break;
				default:
				{
					liMessage__msgs_1128(conf, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__R7okQSC9beJ64olJCnqhGsw_13), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 2), TM__R7okQSC9beJ64olJCnqhGsw_14, NIM_FALSE);
				}
				break;
				}
				genericAssign((void*)(&(*n)), (void*)(&(*bracketExpr)), (&NTItnode__uh9cWvEa5Ty85PXOtuP5emw_));
			}
			LA42_: ;
			asgnRef((void**) (&(*n).typ), t);
		}
		goto LA17_;
		LA38_: ;
		{
			liMessage__msgs_1128(conf, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__R7okQSC9beJ64olJCnqhGsw_15), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 2), TM__R7okQSC9beJ64olJCnqhGsw_16, NIM_FALSE);
		}
		LA17_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41):
	{
		{
			if (!((*x).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 16) || (*x).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24) || (*x).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 27))) goto LA60_;
			asgnRef((void**) (&(*n).typ), t);
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* m;
				m = NIM_NIL;
				{
					NI i_7;
					NI colontmp__3;
					NI i_8;
					i_7 = (NI)0;
					colontmp__3 = (NI)0;
					colontmp__3 = safeLen__ast_3148(n);
					i_8 = ((NI) 0);
					{
						while (1) {
							tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T66_;
							if (!(i_8 < colontmp__3)) goto LA65;
							i_7 = i_8;
							m = (*n)._kind_6.sons->data[i_7];
							T66_ = NIM_NIL;
							T66_ = elemType__types_263(x);
							annotateType__semmacrosanity_69(m, T66_, conf);
							i_8 += ((NI) 1);
						} LA65: ;
					}
				}
			}
		}
		goto LA58_;
		LA60_: ;
		{
			liMessage__msgs_1128(conf, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__R7okQSC9beJ64olJCnqhGsw_17), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 2), TM__R7okQSC9beJ64olJCnqhGsw_18, NIM_FALSE);
		}
		LA58_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 39):
	{
		{
			if (!((*x).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 19))) goto LA71_;
			asgnRef((void**) (&(*n).typ), t);
			{
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* m_2;
				m_2 = NIM_NIL;
				{
					NI i_9;
					NI colontmp__4;
					NI i_10;
					i_9 = (NI)0;
					colontmp__4 = (NI)0;
					colontmp__4 = safeLen__ast_3148(n);
					i_10 = ((NI) 0);
					{
						while (1) {
							tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T77_;
							if (!(i_10 < colontmp__4)) goto LA76;
							i_9 = i_10;
							m_2 = (*n)._kind_6.sons->data[i_9];
							T77_ = NIM_NIL;
							T77_ = elemType__types_263(x);
							annotateType__semmacrosanity_69(m_2, T77_, conf);
							i_10 += ((NI) 1);
						} LA76: ;
					}
				}
			}
		}
		goto LA69_;
		LA71_: ;
		{
			liMessage__msgs_1128(conf, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__R7okQSC9beJ64olJCnqhGsw_19), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 2), TM__R7okQSC9beJ64olJCnqhGsw_20, NIM_FALSE);
		}
		LA69_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 16) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 19):
	{
		{
			if (!((*x).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36) && (*x).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 39))) goto LA82_;
			asgnRef((void**) (&(*n).typ), t);
		}
		goto LA80_;
		LA82_: ;
		{
			liMessage__msgs_1128(conf, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__R7okQSC9beJ64olJCnqhGsw_21), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 2), TM__R7okQSC9beJ64olJCnqhGsw_22, NIM_FALSE);
		}
		LA80_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 15):
	{
		{
			if (!((*x).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) && (*x).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44) || (*x).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1) || (*x).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2) || (*x).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14))) goto LA88_;
			asgnRef((void**) (&(*n).typ), t);
		}
		goto LA86_;
		LA88_: ;
		{
			liMessage__msgs_1128(conf, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__R7okQSC9beJ64olJCnqhGsw_23), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 2), TM__R7okQSC9beJ64olJCnqhGsw_24, NIM_FALSE);
		}
		LA86_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
	{
		{
			if (!((*x).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28) || (*x).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29))) goto LA94_;
			asgnRef((void**) (&(*n).typ), t);
		}
		goto LA92_;
		LA94_: ;
		{
			liMessage__msgs_1128(conf, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__R7okQSC9beJ64olJCnqhGsw_25), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 2), TM__R7okQSC9beJ64olJCnqhGsw_26, NIM_FALSE);
		}
		LA92_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
	{
		{
			if (!((*x).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 21) && (*x).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 22) || (*x).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 24) && (*x).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 26) || (*x).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28) && (*x).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 29) || (*x).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 50))) goto LA100_;
			asgnRef((void**) (&(*n).typ), t);
		}
		goto LA98_;
		LA100_: ;
		{
			liMessage__msgs_1128(conf, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__R7okQSC9beJ64olJCnqhGsw_27), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 2), TM__R7okQSC9beJ64olJCnqhGsw_28, NIM_FALSE);
		}
		LA98_: ;
	}
	break;
	default:
	{
	}
	break;
	}
}
